import ts from 'typescript';

interface TypescriptConfig {
    files?: string[];
    tsconfigPath?: string;
    /** A root directory to resolve relative path entries in the config file to. e.g. outDir */
    basePath?: string;
}

interface GeneratedDoc {
    name: string;
    description: string;
    entries: DocEntry[];
}
interface DocEntry {
    name: string;
    description: string;
    type: string;
    tags: Record<string, string>;
}
interface EntryContext {
    program: ts.Program;
    checker: ts.TypeChecker;
    transform?: Transformer;
    type: ts.Type;
    symbol: ts.Symbol;
}
type Transformer = (this: EntryContext, entry: DocEntry, propertyType: ts.Type, propertySymbol: ts.Symbol) => void;
interface GenerateOptions {
    /**
     * Allow fields with `@internal` tag
     *
     * @defaultValue false
     */
    allowInternal?: boolean;
    /**
     * Modify output property entry
     */
    transform?: Transformer;
}
interface GenerateDocumentationOptions extends GenerateOptions {
    /**
     * Typescript configurations
     */
    config?: TypescriptConfig;
}
/**
 * Generate documentation for properties in an exported type/interface
 */
declare function generateDocumentation(file: string, name: string, options?: GenerateDocumentationOptions): GeneratedDoc | undefined;
declare function generate(program: ts.Program, symbol: ts.Symbol, { allowInternal, transform }: GenerateOptions): GeneratedDoc;

export { type DocEntry as D, type GenerateOptions as G, type TypescriptConfig as T, type GeneratedDoc as a, type GenerateDocumentationOptions as b, generate as c, generateDocumentation as g };
