import {
  __async,
  __objRest,
  __spreadValues,
  generate,
  generateDocumentation,
  getFileSymbol,
  getProgram
} from "./chunk-J5BKKGOH.js";

// src/generate/mdx.ts
import * as path from "path";
var regex = new RegExp("^---type-table---\\r?\\n(?<file>.+?)(?:#(?<name>.+))?\\r?\\n---end---$", "gm");
var defaultTemplates = {
  block: (doc, c) => `### ${doc.name}

${doc.description}

<div className='*:border-b [&>*:last-child]:border-b-0'>${c}</div>`,
  property: (c) => `<div className='text-sm text-muted-foreground py-4'>

<div className="flex flex-row items-center gap-4">
  <code className="text-sm">${c.name}</code>
  <code className="text-muted-foreground">{${JSON.stringify(c.type)}}</code>
</div>

${c.description || "No Description"}

${Object.entries(c.tags).map(([tag, value]) => `- ${tag}:
${replaceJsDocLinks(value)}`).join("\n")}

</div>`
};
function generateMDX(source, _a = {}) {
  var _b = _a, {
    basePath = "./",
    templates: overrides,
    config: options
  } = _b, rest = __objRest(_b, [
    "basePath",
    "templates",
    "config"
  ]);
  const templates = __spreadValues(__spreadValues({}, defaultTemplates), overrides);
  const program = getProgram(options);
  return source.replace(regex, (...args) => {
    const groups = args[args.length - 1];
    const file = path.resolve(basePath, groups.file);
    const fileSymbol = getFileSymbol(file, program);
    if (!fileSymbol)
      throw new Error(`${file} doesn't exist`);
    let docs;
    if (!groups.name) {
      docs = program.getTypeChecker().getExportsOfModule(fileSymbol).map((symbol) => generate(program, symbol, rest));
    } else {
      const symbol = program.getTypeChecker().getExportsOfModule(fileSymbol).find((s) => s.getEscapedName().toString() === groups.name);
      if (!symbol)
        throw new Error(`Type ${groups.name} doesn't exist`);
      docs = [generate(program, symbol, rest)];
    }
    return docs.map(
      (doc) => templates.block(doc, doc.entries.map(templates.property).join("\n"))
    ).join("\n\n");
  });
}
function replaceJsDocLinks(md) {
  return md.replace(new RegExp("{@link (?<link>[^}]*)}", "g"), "$1");
}

// src/generate/file.ts
import * as path2 from "path";
import { mkdir, writeFile, readFile } from "fs/promises";
import fg from "fast-glob";
function generateFiles(options) {
  return __async(this, null, function* () {
    const files = yield fg(options.input, options.globOptions);
    const produce = files.map((file) => __async(this, null, function* () {
      const absolutePath = path2.resolve(file);
      const outputPath = typeof options.output === "function" ? options.output(file) : path2.resolve(
        options.output,
        `${path2.basename(file, path2.extname(file))}.mdx`
      );
      const content = (yield readFile(absolutePath)).toString();
      let result = generateMDX(content, __spreadValues({
        basePath: path2.dirname(absolutePath)
      }, options.options));
      if (options.transformOutput) {
        result = options.transformOutput(outputPath, result);
      }
      yield write(outputPath, result);
      console.log(`Generated: ${outputPath}`);
    }));
    yield Promise.all(produce);
  });
}
function write(file, content) {
  return __async(this, null, function* () {
    yield mkdir(path2.dirname(file), { recursive: true });
    yield writeFile(file, content);
  });
}
export {
  generate,
  generateDocumentation,
  generateFiles,
  generateMDX
};
